@@ -13,19 +13,23 @@ let count =
   Arg.(value & opt int 10 & info ["c"; "count"] ~docv:"COUNT" ~doc)
 
 let msg =
-  let doc = "Overrides the default message to print." in
-  let env = Arg.env_var "CHORUS_MSG" ~doc in
+  let env =
+    let doc = "Overrides the default message to print." in
+    Cmd.Env.info "CHORUS_MSG" ~doc
+  in
   let doc = "The message to print." in
   Arg.(value & pos 0 string "Revolt!" & info [] ~env ~docv:"MSG" ~doc)
 
 let chorus_t = Term.(const chorus $ count $ msg)
 
-let info =
-  let doc = "print a customizable message repeatedly" in
+let cmd =
+  let doc = "Print a customizable message repeatedly" in
   let man = [
     `S Manpage.s_bugs;
-    `P "Email bug reports to <hehey at example.org>." ]
+    `P "Email bug reports to <bugs@example.org>." ]
   in
-  Term.info "chorus" ~version:"v1.0.4" ~doc ~exits:Term.default_exits ~man
+  let info = Cmd.info "chorus" ~version:"v1.1.1" ~doc ~man in
+  Cmd.v info chorus_t
 
-let () = Term.exit @@ Term.eval (chorus_t, info)
+let main () = exit (Cmd.eval cmd)
+let () = main ()
