@@ -5,7 +5,7 @@ let pos l =
 
 let test_pos_left =
   let l = Arg.(value & pos_left 2 string [] & info [] ~docv:"LEFT") in
-  Term.(const pos $ l),
-  Term.info "test_pos" ~doc:"Test pos left"
+  let info = Cmd.info "test_pos" ~doc:"Test pos left" in
+  Cmd.v info Term.(const pos $ l)
 
-let () = Term.(exit @@ eval test_pos_left)
+let () = exit (Cmd.eval test_pos_left)
