@@ -8,7 +8,7 @@ let test_pos =
   let l = Arg.(value & pos_left ~rev 2 string [] & info [] ~docv:"LEFT") in
   let t = Arg.(value & pos ~rev 2 string "undefined" & info [] ~docv:"TWO") in
   let r = Arg.(value & pos_right ~rev 2 string [] & info [] ~docv:"RIGHT") in
-  Term.(const pos $ l $ t $ r),
-  Term.info "test_pos" ~doc:"Test pos rev arguments"
+  let info = Cmd.info "test_pos" ~doc:"Test pos rev arguments" in
+  Cmd.v info Term.(const pos $ l $ t $ r)
 
-let () = Term.(exit @@ eval test_pos)
+let () = exit (Cmd.eval test_pos)
